@@ -61,6 +61,8 @@ package Sidef::Deparse::Perl {
                   Sidef::DataTypes::Number::Quadratic     Sidef::Types::Number::Quadratic
                   Sidef::DataTypes::Number::Quaternion    Sidef::Types::Number::Quaternion
                   Sidef::DataTypes::Number::Complex       Sidef::Types::Number::Complex
+                  Sidef::DataTypes::Number::Polynomial    Sidef::Types::Number::Polynomial
+                  Sidef::DataTypes::Number::Fraction      Sidef::Types::Number::Fraction
                   Sidef::DataTypes::Range::Range          Sidef::Types::Range::Range
                   Sidef::DataTypes::Range::RangeNumber    Sidef::Types::Range::RangeNumber
                   Sidef::DataTypes::Range::RangeString    Sidef::Types::Range::RangeString
