@@ -294,17 +294,13 @@ package Sidef::Types::Array::Array {
             my ($obj1, $obj2) = @_;
 
             my $refaddr1 = Scalar::Util::refaddr($obj1);
-            my $refaddr2 = Scalar::Util::refaddr($obj2);
 
             exists($addr{$refaddr1})
               && return $addr{$refaddr1};
 
-            exists($addr{$refaddr2})
-              && return $addr{$refaddr2};
-
             my @array;
 
-            $addr{$refaddr2} = $addr{$refaddr1} = bless(\@array, ref($obj1));
+            $addr{$refaddr1} = bless(\@array, ref($obj1));
 
             for my $i (0 .. $#{$obj1}) {
                 if (ref($obj1->[$i]) eq __PACKAGE__ or UNIVERSAL::isa($obj1->[$i], __PACKAGE__)) {
@@ -2727,7 +2723,7 @@ package Sidef::Types::Array::Array {
     *unique_prefixes = \&uniq_prefs;
 
     sub contains {
-        my ($self, $obj) = @_;
+        my ($self, $obj, @extra) = @_;
 
         if (ref($obj) eq 'Sidef::Types::Block::Block') {
             foreach my $item (@$self) {
@@ -2739,9 +2735,25 @@ package Sidef::Types::Array::Array {
             return (Sidef::Types::Bool::Bool::FALSE);
         }
 
-        foreach my $item (@$self) {
-            if ($item eq $obj) {
-                return (Sidef::Types::Bool::Bool::TRUE);
+        my $end = $#$self;
+
+        foreach my $i (0 .. $end) {
+            if ($self->[$i] eq $obj) {
+
+                my $ok = 1;
+                my $j  = $i;
+
+                foreach my $obj (@extra) {
+                    if (++$j <= $end and $self->[$j] eq $obj) {
+                        ## ok
+                    }
+                    else {
+                        $ok = 0;
+                        last;
+                    }
+                }
+
+                $ok && return (Sidef::Types::Bool::Bool::TRUE);
             }
         }
 
@@ -3310,6 +3322,19 @@ package Sidef::Types::Array::Array {
     sub cartesian {
         my ($self, $block) = @_;
 
+        if (!defined($block) and Sidef::Types::Number::Number::HAS_PRIME_UTIL) {
+            my @result;
+
+            Math::Prime::Util::forsetproduct(
+                sub {
+                    push @result, bless [@_];    # don't bless \@_
+                },
+                map { [@$_] } @$self
+                                            );
+
+            return bless \@result;
+        }
+
         require Algorithm::Loops;
 
         my $iter = Algorithm::Loops::NestedLoops([map { [@$_] } @$self]);
